import { useEffect } from "react";
import { Link } from "wouter";
import Header from "@/components/header";
import Footer from "@/components/footer";
import AIChatbot from "@/components/ai-chatbot";

export default function ServicesPage() {
  useEffect(() => {
    // Setup scroll animations
    const observerOptions = {
      threshold: 0.1,
      rootMargin: '0px 0px -50px 0px'
    };

    const observer = new IntersectionObserver((entries) => {
      entries.forEach((entry) => {
        if (entry.isIntersecting) {
          entry.target.classList.add('visible');
        }
      });
    }, observerOptions);

    const animateElements = document.querySelectorAll('.fade-in');
    animateElements.forEach((el) => {
      observer.observe(el);
    });

    return () => {
      animateElements.forEach((el) => {
        observer.unobserve(el);
      });
    };
  }, []);

  const services = [
    {
      icon: "fas fa-brain",
      title: "AI интеграция",
      description: "Интегрираме изкуствен интелект в бизнес процесите ви за максимална ефективност и автоматизация.",
      features: [
        "Персонализирани AI алгоритми",
        "Автоматизирано вземане на решения",
        "Предиктивна аналитика",
        "Машинно обучение модели"
      ],
      link: "/services/ai-integration"
    },
    {
      icon: "fas fa-cogs",
      title: "Автоматизация",
      description: "Автоматизираме рутинните задачи и оптимизираме работните процеси за по-голяма продуктивност.",
      features: [
        "Workflow автоматизация",
        "CRM интеграция",
        "Автоматизирани отчети",
        "Email маркетинг автоматизация"
      ],
      link: "/services/automation"
    },
    {
      icon: "fas fa-lightbulb",
      title: "AI консултиране и оценка на готовността",
      description: "Анализираме нуждите и потенциала на вашата организация и препоръчваме най-добрия AI път за растеж.",
      features: [
        "AI стратегически план",
        "Анализ на бизнес процесите",
        "ROI оценка на AI решения",
        "Персонализирани препоръки"
      ],
      link: "/services/ai-consulting"
    },
    {
      icon: "fas fa-graduation-cap",
      title: "Обучение на екипи за работа с AI",
      description: "Провеждаме практически обучения и уъркшопи, за да могат вашите служители уверено да използват AI решенията.",
      features: [
        "Практически уъркшопи",
        "Персонализирани курсове",
        "Сертифициране на служители",
        "Ongoing поддръжка"
      ],
      link: "/services/ai-training"
    }
  ];

  return (
    <>
      <Header />
      <main className="pt-16">
        {/* Hero Section */}
        <section className="min-h-[60vh] flex items-center justify-center px-4 bg-gradient-to-br from-slate-50 to-blue-50 relative overflow-hidden">
          <div className="absolute top-0 right-0 w-96 h-96 bg-gradient-to-r from-purple-400/20 to-blue-400/20 rounded-full blur-3xl float-animation"></div>
          
          <div className="text-center max-w-4xl z-10 relative">
            <h1 className="text-5xl md:text-6xl font-bold mb-6 gradient-text leading-tight fade-in">
              Нашите услуги
            </h1>
            
            <p className="text-xl md:text-2xl mb-8 text-gray-600 font-light max-w-2xl mx-auto fade-in">
              Професионални дигитални решения, адаптирани към нуждите на вашия бизнес
            </p>
          </div>
        </section>

        {/* Services Grid */}
        <section className="py-20 px-4 max-w-7xl mx-auto">
          <div className="grid grid-cols-1 md:grid-cols-2 xl:grid-cols-4 gap-8">
            {services.map((service, index) => (
              <div 
                key={index} 
                className="service-card glass rounded-3xl p-8 transition-all duration-300 hover:bg-white/40 fade-in flex flex-col h-full"
              >
                <div className="text-5xl mb-6 gradient-text text-center">
                  <i className={service.icon}></i>
                </div>
                
                <h3 className="text-2xl font-semibold mb-4 text-gray-800 text-center">
                  {service.title}
                </h3>
                
                <p className="text-gray-600 leading-relaxed mb-6 text-center">
                  {service.description}
                </p>
                
                <ul className="space-y-3 mb-8 flex-grow">
                  {service.features.map((feature, idx) => (
                    <li key={idx} className="flex items-center text-gray-700">
                      <i className="fas fa-check text-green-500 mr-3"></i>
                      {feature}
                    </li>
                  ))}
                </ul>
                
                <div className="mt-auto">
                  <Link href={service.link}>
                    <button className="w-full gradient-button py-3 rounded-xl font-semibold transition-all hover:scale-105">
                      Научете повече
                    </button>
                  </Link>
                </div>
              </div>
            ))}
          </div>
        </section>

        {/* CTA Section */}
        <section className="py-20 px-4 bg-gradient-to-r from-purple-600 to-blue-600 text-white">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-4xl md:text-5xl font-bold mb-6 fade-in">
              Готови за дигитална трансформация?
            </h2>
            <p className="text-xl mb-8 opacity-90 fade-in">
              Свържете се с нас за безплатна консултация и персонализирана оферта
            </p>
            <a 
              href="/contact"
              className="bg-white text-purple-600 px-8 py-4 rounded-full text-lg font-semibold hover:bg-gray-100 transition-all transform hover:scale-105 fade-in inline-block"
            >
              Безплатна консултация
            </a>
          </div>
        </section>
      </main>
      <Footer />
      <AIChatbot />
    </>
  );
}